#
# spec file for package tls
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tls
Summary:        Tcl Binding for the OpenSSL Library
License:        BSD-3-Clause
Group:          Development/Libraries/Tcl
Version:        1.7.14
Release:        lp150.2.2
Url:            http://tls.sourceforge.net
Source0:        tcl%name-%version.tar.gz
Patch0:         tls-fix-channel-state.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(tcl)

%description
This Tcl extension provides a generic binding to OpenSSL, utilizing
the Tcl_StackChannel API for Tcl 8.2 and higher. The sockets behave
exactly the same as channels created using Tcl's built-in socket
command with additional options for controlling the SSL session.

%prep
%setup -q -n tcl%name-%version
%patch0

%build
%configure \
	--enable-deterministic \
	--enable-ssl-fastpath
make %{?_smp_mflags}

%check
cat > known-failures <<EOF
ciphers-1.4
ciphers-1.3
tls-bug58-1.0
EOF
make test 2>&1 | tee testresults
grep FAILED testresults | grep -Fqvf known-failures && exit 1 ||:

%install
make install \
	DESTDIR=%buildroot \
	PKG_HEADERS= \
	libdir=%_libdir/tcl

%files
%defattr(-,root,root,-)
%doc ChangeLog README.txt license.terms tls.htm
%_libdir/tcl

%changelog
* Thu Feb  1 2018 max@suse.com
- Fix the logic to fail on unexpected testsuite failures.
* Fri Dec 29 2017 max@suse.com
- Update to version 1.7.14 for compatibility with OpenSSL 1.1.
- Add tls-fix-channel-state.patch to prevent implicit changes of
  encoding, translation and blocking mode when importing a socket.
  https://core.tcl.tk/tcltls/info/f798e2ea12
* Thu Oct  8 2015 max@suse.com
- Update to version 1.6.7 to incorporate the latest upstream fixes.
  This obsoletes tls-ciphers.patch and tls-enable-tls1.patch.
* Wed Nov 26 2014 gber@opensuse.org
- update to version 1.6.3 (from CVS):
  * tls.c (MiscObjCmd): Fixed non-static string array used in call
    of Tcl_GetIndexFromObj(). Memory smash waiting to happen.
    Thanks to Brian Griffin for alerting us all to the problem.
  * tls.c: Applied Jeff's patch from
    http://www.mail-archive.com/aolserver@listserv.aol.com/msg12356.html
  * tls.c (StatusObjCmd): memleak: free peer if loaded.
    [Bug 3041925]
  * tls.tcl (tls::socket): some socket implementations have a -type
    support (e.g. for inet6).
- rebased tls-fix-ciphers.patch
- modified tls-enable-tls1.patch to only enable tls1 by default
  and to update the documentation
* Wed Nov 19 2014 gber@opensuse.org
- disable test tlsIO-2.10, reading from a closed socket raises an
  exception with tcl >= 8.6.2 resulting in a timeout and failed
  test
* Wed Jun 25 2014 max@suse.com
- Enable TLS1 by default to avoid problems with servers that
  reject anything else (tls-enable-tls1.patch).
* Tue Aug  4 2009 max@suse.de
- Query openssl for the ciphers it supports instead of comparing
  against a hardcoded list to make the test independent of the
  openssl version.
- Remove tls.h from the package.
* Tue Apr 22 2008 max@suse.de
- Ignore test tlsIO-12.3, because it fails on loaded machines.
* Thu Apr  3 2008 max@suse.de
- New version: 1.6
  * Fix a memleak in tls.c
  * Use better Eval APIs, cleaner Tcl_Obj-handling
  * fix handshake on non-blocking sockets
- Adjust to the new Tcl file system layout.
* Fri Oct 20 2006 max@suse.de
- Patched cipher tests to match cipher list of openssl-0.98d.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 max@suse.de
- Update to CVS snapshot of version 1.5.1.
* Wed Jun 29 2005 max@suse.de
- Moved the sctipt library to /usr/share/tcl .
* Wed Jun  1 2005 max@suse.de
- Temporarily disabled test tlsIO-12.3, because it sometimes fails
  in a way that is hard to track down.
  This needs further inspection.
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Fri Feb 27 2004 max@suse.de
- New version: 1.5.0
* Wed Feb 25 2004 hmacht@suse.de
- building as non-root (# norootforbuild)
* Wed Jun  4 2003 max@suse.de
- New package: tls-1.4.1
- Tcl bindings to SSL
